@@ -2,18 +2,25 @@ int
 getFloatOpt(int argc, char **argv, int i, float *value, int force)
 {
   char *end;
+  double v;
 
   if( ++i>=argc ) goto nothingFound;
 
-  *value = (float)strtod(argv[i], &end);
+  errno = 0;
+  v = strtod(argv[i], &end);
 
   /***** check for conversion error */
   if( end==argv[i] ) goto nothingFound;
 
   /***** check for surplus non-whitespace */
-  while( isspace(*end) ) end+=1;
+  while( isspace((int) *end) ) end+=1;
   if( *end ) goto nothingFound;
 
+  /***** check for overflow */
+  checkFloatConversion(v, argv[i-1], argv[i]);
+
+  *value = (float)v;
+
   return i;
 
 nothingFound:
