@@ -9,6 +9,7 @@ getFloatOpts(int argc, char **argv, int i,
 {
   int alloced, used;
   char *end;
+  double v;
 
   if( i+cmin >= argc ) {
     fprintf(stderr, 
@@ -37,14 +38,20 @@ outMem:
       if( !*values ) goto outMem;
     }
 
-    (*values)[used] = (float)strtod(argv[used+i+1], &end);
+    errno = 0;
+    v = strtod(argv[used+i+1], &end);
 
     /***** check for conversion error */
     if( end==argv[used+i+1] ) break;
 
     /***** check for surplus non-whitespace */
-    while( isspace(*end) ) end+=1;
+    while( isspace((int) *end) ) end+=1;
     if( *end ) break;
+
+    /***** check for overflow */
+    checkFloatConversion(v, argv[i], argv[i+used+1]);
+    
+    (*values)[used] = (float)v;
   }
     
   if( used<cmin ) {
