@@ -2,18 +2,29 @@ int
 getIntOpt(int argc, char **argv, int i, int *value, int force)
 {
   char *end;
+  long v;
 
   if( ++i>=argc ) goto nothingFound;
 
-  *value = (int)strtol(argv[i], &end, 10);
+  errno = 0;
+  v = strtol(argv[i], &end, 0);
 
   /***** check for conversion error */
   if( end==argv[i] ) goto nothingFound;
 
   /***** check for surplus non-whitespace */
-  while( isspace(*end) ) end+=1;
+  while( isspace((int) *end) ) end+=1;
   if( *end ) goto nothingFound;
 
+  /***** check if it fits into an int */
+  if( errno==ERANGE || v>(long)INT_MAX || v<(long)INT_MIN ) {
+    fprintf(stderr, 
+	    "%s: parameter `%s' of option `%s' to large to represent\n",
+	    Program, argv[i], argv[i-1]);
+    exit(EXIT_FAILURE);
+  }
+  *value = (int)v;
+
   return i;
 
 nothingFound:
