@@ -11,37 +11,35 @@
 ## The generated C-code is returned as the function result.
 ##
 proc genStruct {} {
-  global D L
+  global D typeMap
 
   set res "typedef struct s_Cmdline \{\n"
   
-  foreach opt $L {
+  foreach opt $D(opts) {
+    if {[string match "--" $opt]} continue
     append res \
 	"  /***** $opt: $D($opt,usage) */\n"\
-	"  char $D($opt,name)P;\n"
+	"  char $D($opt,var)P;\n"
     
-    if { $D($opt,type)=="flag" } continue
+    if { $D($opt,type)=="Flag" } continue
 
-    if { $D($opt,cmax) == 1 } {
-      append res "  $D($opt,type) $D($opt,name);\n"
-    } else {
-      append res "  $D($opt,type) *$D($opt,name);\n"
-    }
-
-    append res "  int $D($opt,name)C;\n"
+    foreach {cmin cmax} $D($opt,count) break
+    set ast [expr {$cmax==1 ? "" : "*"}]
+    append res \
+	"  $typeMap(C,$D($opt,type)) $ast$D($opt,var);\n" \
+	"  int $D($opt,var)C;\n"
 
   }
   append res \
       "  /***** uninterpreted command line parameters */\n"\
-      "  int argc;\n"\
+      "  int argc;\n" \
       "  /*@null*/char **argv;\n"
 
   ## Do we generate a copy of the command line as one string?
-  global argvString
-  if [info exist argvString] {
+  if [info exist D(commandline)] {
     append res \
 	"  /***** the whole command line concatenated */\n"\
-	"  char *$argvString;\n"
+	"  char *$D(commandline);\n"
   }
   append res \
       "\} Cmdline;\n"
